<?php
/*
Plugin Name: TablePressNoCacheCommentExtension
Plugin URI: http://blog.tremlas.com/TablePressNoCacheCommentExtension-plugin-details/
Description: Suppress the html comment from TablePress that indicates the rendered table came from the cache
Version: 3.76.0
Author: David Vines
Author URI: http://blog.tremlas.com
License: GPLv2
*/
/* © Copyright 2020 David Vines
 * 
 * TablePressNoCacheCommentExtension is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License, version 2, as published by
 * the Free Software Foundation.
 *
 * TablePressNoCacheCommentExtension is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with WordPress. If not, see https://www.gnu.org/licenses/gpl-2.0.html.
 * 
*/

function djv_TablePressNoCacheCommentExtension_no_cache_comment($content) {
 return ""; // Ignore the comment
}
add_filter( 'tablepress_cache_hit_comment', 'djv_TablePressNoCacheCommentExtension_no_cache_comment');

/* --------------------- Functions for updating plugins ------------------------------ */
function djv_TablePressNoCacheCommentExtension_get_remote_update_from( $urlbase, $slug ) {
 $url = $urlbase . '/wp-content/uploads/jsons/' . $slug . '.json';
 $remote =  wp_remote_get( $url, array( 'timeout' => 10, 'headers' => array( 'Accept' => 'application/json' ) ) );
 if ( !is_wp_error( $remote ) && isset( $remote['response']['code'] ) && 200 == $remote['response']['code'] && ! empty( $remote['body'] ) ) {
  $remote['urlbase'] = $urlbase;
 }
 return $remote;
}
function djv_TablePressNoCacheCommentExtension_get_remote_update_info( $slug ) {
 $remote = get_transient( 'djv_update_' . $slug );
 if (false == $remote) {
  if ( 'cubi' == gethostname() ) {
   $remote = djv_TablePressNoCacheCommentExtension_get_remote_update_from( 'http://cubi.internal', $slug );
   if (false !== $remote) {
    set_transient( 'djv_update_' . $slug, $remote, 10 ); // Save for only 10 seconds here
   }
  }
 }
 if (false == $remote || is_wp_error($remote) || !isset( $remote['response']['code'] ) || 200 !== $remote['response']['code'] || empty( $remote['body'] ) ) {
  $remote = djv_TablePressNoCacheCommentExtension_get_remote_update_from( 'https://blog.tremlas.com', $slug );
  set_transient( 'djv_update_' . $slug, $remote, 43200 ); // Save for 12 hours
 }
 if ( !is_wp_error( $remote ) && isset( $remote['response']['code'] ) && 200 == $remote['response']['code'] && ! empty( $remote['body'] ) ) {
  $body = json_decode( $remote['body'] );
  $info = new StdClass();
  $info->name = 'TablePressNoCacheCommentExtension';
  $info->slug = $slug;
  $info->version = $body->version;
  $info->requires = $body->requires;
  $info->author = '<a href="' . $body->author_profile . '">' . $body->author . '</a>';
  $info->download_link = $remote['urlbase'] . '/' . $body->download_url;
  $info->trunk = $remote['urlbase'] . '/' . $body->download_url;
  $info->last_updated = $body->last_updated;
  $info->sections = array(
    'description'  => implode( "\n", $body->sections->description ),
    'installation' => implode( "\n", $body->sections->installation ),
    'changelog'    => implode( "\n", $body->sections->changelog ),
  );
  $info->homepage = $remote['urlbase'] . '/' . $body->homepage;
  return $info;
 }
 return false;
}

function djv_TablePressNoCacheCommentExtension_check_for_update( $name, $slug ) {
 $info = djv_TablePressNoCacheCommentExtension_get_remote_update_info( $slug );
 if ( false == $info ) {
  return false;
 }
 if ( version_compare( '3.76.0', $info->version, '<' ) && version_compare( $info->requires, get_bloginfo( 'version' ), '<' ) ) {
  $update = (object) array(
    'id'            => $name,
    'slug'          => $slug,
    'plugin'        => $name,
    'new_version'   => $info->version,
    'url'           => $info->homepage,
    'package'       => $info->download_link,
    'icons'         => array(),
    'banners'       => array(),
    'banners_rtl'   => array(),
    'tested'        => '',
    'requires_php'  => '',
    'compatability' => new StdClass()
  );
  return $update;
 } else {
  return false;
 }
}

function djv_TablePressNoCacheCommentExtension_pre_set_site_transient_update_plugins( $transient ) {
 // Check for update
 $pluginphp = 'TablePressNoCacheCommentExtension/TablePressNoCacheCommentExtension.php';
 $pluginslug = 'TablePressNoCacheCommentExtension';
 $update = djv_TablePressNoCacheCommentExtension_check_for_update( $pluginphp, $pluginslug );
 if ( $update ) {
  $transient->response[$pluginphp] = $update;
 } else {
  // No update
  $item = (object) array(
    'id'            => $pluginphp,
    'slug'          => $pluginslug,
    'plugin'        => $pluginphp,
    'new_version'   => '3.76.0',
    'url'           => '',
    'package'       => '',
    'icons'         => array(),
    'banners'       => array(),
    'banners_rtl'   => array(),
    'tested'        => '',
    'requires_php'  => '',
    'compatability' => new StdClass()
  );
  $transient->no_update[$pluginphp] = $item;
 }
 return $transient;
}
add_filter( 'pre_set_site_transient_update_plugins', 'djv_TablePressNoCacheCommentExtension_pre_set_site_transient_update_plugins' );

function djv_TablePressNoCacheCommentExtension_plugin_info( $result, $action, $args ) {
 $slug = 'TablePressNoCacheCommentExtension';
 if ( 'plugin_information' !== $action ) {
  return $result;
 }
 if ( $slug !== $args->slug) {
  return $result;
 }
 return djv_TablePressNoCacheCommentExtension_get_remote_update_info( $slug );
}
add_filter( 'plugins_api', 'djv_TablePressNoCacheCommentExtension_plugin_info', 10, 3 );


?>